# Clustering was performed for each patient with Dollo Parsimony, an R wrapper for phylip37,
# with the following R code where i is the index for each patient.

function(zeroOneMatrix, bsIterations, outDir, pID) {
	# zeroOneMatrix is a binary matrix;
	# outDir is where tree will be written (not used here);
	# pID is patient ID;
	# bsIteration are number of bootstrap iterations.
	library(phangorn);
	library(Rphylip);
	method="dollo"
	treeDRooted = Rdollop(
		zeroOneMatrix,
		method=method,
		quite=TRUE,
		path='../Exome/Clonality/DolloParsimony/phylip-3.695/phylip-3.695/exe/'
	)
	if(class(treeDRooted) == "multiPhylo") treeDRooted = treeDRooted[[1]]
	print(treeDRooted)

	# since dollo parsimony can return more than one tree sometimes, we
	# extend the boot.phylo() from ape (to my.boot.phylo())
	bValuesDP = my.boot.phylo(
		treeDRooted,
		zeroOneMatrix,
		FUN=function(xx) {
			Rdollop(xx, method=method, quite=TRUE, path='phylip-3.695/phylip-3.695/exe/')
		},
		B = bsIterations,
		trees=T,
		rooted=T
	)
	print("After bootstrap analysis")

	# convert to percentage
	bValues = bValuesDP$BP/bsIterations * 100;

	# colors for nodes
	pdf(paste0(outDir, '/', 'tree_', pID, '.bootstrapDollo.pdf'))
	plot(treeDRooted, use.edge.length = F);
	nodelabels(bValues, frame = 'rect')
	title(paste0('Patient ', pID,': Dollo Parsimony tree with bootstrap percentage'))
	dev.off()
	25

	# write the tree as newick
	write.tree(treeDRooted, file=paste0(outDir,'/n', pID, '_rooted_Dollo.tree'))
	write.tree(bValuesDP$trees, file=paste0(outDir,'/n', pID, '_bsTrees_Dollo.tree'))
}
